# molab

This module is for use in conjuction with the Terraform deployments of the Morpheus training labs.
If you do not have access to this capability, this module is not for you.

For thos e that do, you can reference the docs at https://morpheus_training.gitlab.io/molab/